@@ -115,7 +115,7 @@ class Dataset(EntityBase):
 
         return response.raw
 
-    def get_entities(self, since=None, limit=None, start=None, history=True, deleted=True, reverse=False,
+    def get_entities(self, do_transit_decoding=True, since=None, limit=None, start=None, history=True, deleted=True, reverse=False,
                      uncommitted=None,
                      subset=None, expected_node_id=None, **kwargs
                      ):
@@ -128,9 +128,9 @@ class Dataset(EntityBase):
                                                       deleted=deleted, reverse=reverse, uncommitted=uncommitted,
                                                       subset=subset, expected_node_id=expected_node_id, **kwargs
                                                       )
-        return entity_json.parse_json_stream(entities_stream)
+        return entity_json.parse_json_stream(entities_stream, do_transit_decoding=do_transit_decoding)
 
-    def get_entity(self, entity_id, offset=None, **kwargs):
+    def get_entity(self, entity_id, do_transit_decoding=True, offset=None, **kwargs):
         """Returns the specified entity if it exist, or None if the entity does not exist.
 
         :param entity_id:
@@ -145,7 +145,7 @@ class Dataset(EntityBase):
         if response.status_code == 404:
             # No such element.
             return None
-        return entity_json.parse_entity(response.content.decode("utf-8"))
+        return entity_json.parse_entity(response.content.decode("utf-8"), do_transit_decoding=do_transit_decoding)
 
     def post_entities(self, entities, force=None, **kwargs):
         """This posts the specified entities to the dataset."""
