@@ -63,7 +63,7 @@ class Pipe(EntityBase):
         return runtime.get("execution-dataset")
 
     def get_log_entities(self, since=None, limit=None, start=None, history=True, deleted=True, reverse=False,
-                         accept="application/json", expected_node_id=None, method="GET",
+                         do_transit_decoding=True, accept="application/json", expected_node_id=None, method="GET",
                          **kwargs):
         """Returns the content of the execution dataset using the /pipes/{pipe}/log API """
         url = self._connection.get_pipe_log_url(self.id)
@@ -98,15 +98,20 @@ class Pipe(EntityBase):
         response = request_func(url, allowable_response_status_codes=[200], stream=True, params=params,
                                 headers=headers, **kwargs)
 
-        return entity_json.parse_json_stream(response.raw)
+        return entity_json.parse_json_stream(response.raw, do_transit_decoding=do_transit_decoding)
 
     @property
     def runtime(self):
         return copy.deepcopy(self._raw_jsondata["runtime"])
 
-    def get_entities(self, since=None, limit=None, stage=None, **kwargs):
+    @property
+    def graph(self):
+        return copy.deepcopy(self._raw_jsondata["graph"])
+
+    def get_entities(self, since=None, limit=None, stage=None, do_transit_decoding=True, **kwargs):
         """This returns a generator for iterating over the entities of the specified stage
         of this pipe.
+        :param do_transit_decoding: bool determining if transit decoding should be performed
         :param since:
         :param limit: The maximum number of entities to return. A value of None means return all the entities.
         :param stage:
@@ -125,7 +130,7 @@ class Pipe(EntityBase):
         response = self._connection.do_get_request(url, allowable_response_status_codes=[200],
                                                    stream=True, params=params, **kwargs)
 
-        return entity_json.parse_json_stream(response.raw)
+        return entity_json.parse_json_stream(response.raw, do_transit_decoding=do_transit_decoding)
 
     def post_entities(self, entities,
                       is_full=None,
@@ -208,6 +213,9 @@ class Pipe(EntityBase):
             try:
                 self.update_raw_jsondata_from_url(self._connection.get_pipe_url(self.id), **kwargs)
             except ExceptionWithResponse as e:
+                if e.response.status_code == 404:
+                    # This pipe has been deleted according to the API, we can return
+                    return
                 elapsetime = time.monotonic() - starttime
                 if elapsetime > timeout:
                     raise AssertionError(
